unit text_canvas;

{$mode objfpc}{$H+}

interface

uses Classes, fpg_base, fpg_widget, tools_unit;

type

	TTextCanvas = class(TfpgWidget)
	private

		canvasText: string;
		dropRepaint: boolean;

		procedure DrawCanvas;

	protected

		procedure HandlePaint; override;

	public

		constructor Create(AOwner: TComponent); override;
		procedure clearText();
		procedure addText(textToAdd: UTF8String);
		procedure addText(text1ToAdd: UTF8String; text2ToAdd: UTF8String);
		procedure addLine(textToAdd: UTF8String);
		procedure addLine(text1ToAdd: UTF8String; text2ToAdd: UTF8String);

	end;

implementation

{ TTextCanvas }

// uses fpg_gdi; // Z nejakého dôvodu už netreba. Asi sme to potrebovali pri staršej verzii plátna…


procedure TTextCanvas.DrawCanvas;
begin
	Canvas.DrawText(10, 10, canvasText)
end;

procedure TTextCanvas.HandlePaint;
begin
	Canvas.Clear(clWindowBackground);
	// Canvas.Clear(clWhite);
	DrawCanvas;
end;


constructor TTextCanvas.Create(AOwner: TComponent);
begin
	inherited Create(AOwner);
	canvasText := '';
	dropRepaint := false;
	Repaint;
end;

procedure TTextCanvas.clearText();
begin
	canvasText := '';
	if dropRepaint then dropRepaint := false else Repaint;
end;

procedure TTextCanvas.addText(textToAdd: UTF8String);
begin
	canvasText := ConcatUTF8Strings(canvasText, textToAdd);
	if dropRepaint then dropRepaint := false else Repaint;
end;

procedure TTextCanvas.addText(text1ToAdd: UTF8String; text2ToAdd: UTF8String);
begin
	canvasText := ConcatUTF8Strings(canvasText, text1ToAdd);
	canvasText := ConcatUTF8Strings(canvasText, text2ToAdd);
	if dropRepaint then dropRepaint := false else Repaint;
end;

procedure TTextCanvas.addLine(textToAdd: UTF8String);
var shouldRepaint: boolean;
begin
	shouldRepaint := not dropRepaint;
	dropRepaint := true;
	addText(textToAdd);
	canvasText := ConcatUTF8Strings(canvasText, #10);
	if shouldRepaint then Repaint;
end;

procedure TTextCanvas.addLine(text1ToAdd: UTF8String; text2ToAdd: UTF8String);
var shouldRepaint: boolean;
begin
	shouldRepaint := not dropRepaint;
	dropRepaint := true;
	addText(text1ToAdd, text2ToAdd);
	canvasText := ConcatUTF8Strings(canvasText, #10);
	if shouldRepaint then Repaint;
end;

end.